Br class
A utility class for defining border styles and configurations.
Constructors
- Br()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- circle ↔ BorderRadius
-
borderRadius: Br.circlegetter/setter pair
Static Methods
-
all(
{Color? color, double? width, BorderStyle style = BorderStyle.solid, double strokeAlign = BorderSide.strokeAlignInside}) → BoxBorder -
border: Br.all(color: Colors.black12) -
except(
List< String> except, {Color? color, double? width, BorderStyle style = BorderStyle.solid}) → BoxBorder -
border: Br.except(['t']) -
only(
List< String> only, {Color? color, double? width, dynamic except = false, BorderStyle style = BorderStyle.solid}) → BoxBorder -
Creates a
BoxBorderwith specific sides enabled. -
radius(
double value, {List< String> ? except}) → BorderRadius -
borderRadius: Br.radius(15) borderRadius: Br.radius(15, except: ['bl', 'br']) -
radiusOnly(
{double? tl, double? tr, double? bl, double? br, double? tlr, double? blr, double? ltb, double? rtb}) → BorderRadius -
borderRadius: Br.radiusOnly()
Constants
- none → const BoxBorder
-
border: Br.none - zero → const BorderRadius
-
borderRadius: Br.zero