Bx class
A class providing a utility method for creating box shadows.
Constructors
- Bx()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
gradient(
List< Color> colors, {AlignmentGeometry? begin, AlignmentGeometry? end, List<double> ? stops = const [0.0, 1.0], TileMode? mode}) → Gradient - Creates a linear gradient with the specified colors and optional start, end, stops, and tile mode parameters.
-
radialGradient(
List< Color> colors, {AlignmentGeometry? center, double radius = 0.5, List<double> ? stops, TileMode mode = TileMode.clamp}) → Gradient - Creates a radial gradient with the specified colors and optional center, radius, stops, and tile mode parameters.
-
shadow(
Color color, {double? blur, double? spread, double? x, double? y}) → BoxShadow - Creates a box shadow with the specified color and optional blur, spread, x, and y parameters.
-
sweepGradient(
List< Color> colors, {AlignmentGeometry? center, double startAngle = 0.0, double endAngle = 2 * 3.141592653589793, List<double> ? stops, TileMode mode = TileMode.clamp}) → Gradient - Creates a sweep gradient with the specified colors and optional center, startAngle, endAngle, stops, and tile mode parameters.